@@ -7,7 +7,7 @@ use warnings;
 use base 'Class::Accessor::Complex';
 
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 __PACKAGE__->mk_new;
@@ -153,6 +153,8 @@ sub yaml_dump {
 
 __END__
 
+
+
 =head1 NAME
 
 String::FlexMatch - flexible ways to match a string
@@ -223,17 +225,64 @@ A setup like this was the reason for writing this class. If you find
 any other uses for it, please let me know so this manpage can be expanded
 with a few cookbook-style examples.
 
+String::FlexMatch inherits from L<Class::Accessor::Complex>.
+
+The superclass L<Class::Accessor::Complex> defines these methods and
+functions:
+
+    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
+    mk_array_accessors(), mk_boolean_accessors(),
+    mk_class_array_accessors(), mk_class_hash_accessors(),
+    mk_class_scalar_accessors(), mk_concat_accessors(),
+    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
+    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
+    mk_set_accessors(), mk_singleton()
+
+The superclass L<Class::Accessor> defines these methods and functions:
+
+    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
+    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
+    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
+    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
+    mk_wo_accessors(), mutator_name_for(), set()
+
+The superclass L<Class::Accessor::Installer> defines these methods and
+functions:
+
+    install_accessor(), subname()
+
+=head1 METHODS
+
+=over 4
+
+=item new
+
+    my $obj = String::FlexMatch->new;
+    my $obj = String::FlexMatch->new(%args);
+
+Creates and returns a new object. The constructor will accept as arguments a
+list of pairs, from component name to initial value. For each pair, the named
+component is initialized by calling the method of the same name with the given
+value. If called with a single hash reference, it is dereferenced and its
+key/value pairs are set as described before.
+
+=back
+
 =head1 TAGS
 
 If you talk about this module in blogs, on del.icio.us or anywhere else,
 please use the C<stringflexmatch> tag.
 
+=head1 VERSION 
+                   
+This document describes version 0.11 of L<String::FlexMatch>.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-string-flexmatch@rt.cpan.org>, or through the web interface at
+C<<bug-string-flexmatch@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -257,5 +306,6 @@ Copyright 2004-2007 by Marcel GrE<uuml>nauer
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
